==> ejc-jlcost-impl-3.0.0-20240514.101419-26-sources.jar: com/ejianc/business/jlcost/payout/service/impl/SettleBpmServiceImpl.java <==
package com.ejianc.business.jlcost.payout.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.ejianc.business.jlcost.payout.bean.SettleEntity;
import com.ejianc.business.jlcost.payout.service.ISettleService;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.BillStateEnum;
import org.springframework.stereotype.Service;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.springframework.beans.factory.annotation.Autowired;

@Service("settle")
public class SettleBpmServiceImpl implements ICommonBusinessService {

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
	private ISettleService settleService;

	/**
	 * 提交前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {

		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		SettleEntity entity = settleService.selectById(billId);
		LambdaQueryWrapper<SettleEntity> queryWrapper = new LambdaQueryWrapper<>();
		queryWrapper.eq(SettleEntity::getContractId, entity.getContractId());
		queryWrapper.eq(SettleEntity::getProjectId, entity.getProjectId());
		queryWrapper.notIn(SettleEntity::getBillState, BillStateEnum.PASSED_STATE.getBillStateCode(), BillStateEnum.COMMITED_STATE.getBillStateCode());
		SettleEntity settleEntity = settleService.getOne(queryWrapper, false);
		if (null != settleEntity) {
			throw new BusinessException("该合同在该项目上存在未完成的结算单【" + settleEntity.getBillCode() + "】,不能弃审或撤回！");
		}
		queryWrapper = new LambdaQueryWrapper<>();
		queryWrapper.eq(SettleEntity::getContractId, entity.getContractId());
		queryWrapper.eq(SettleEntity::getProjectId, entity.getProjectId());
		queryWrapper.in(SettleEntity::getBillState, BillStateEnum.PASSED_STATE.getBillStateCode(), BillStateEnum.COMMITED_STATE.getBillStateCode());
		queryWrapper.gt(SettleEntity::getCreateTime, entity.getCreateTime());
		if (settleService.count(queryWrapper) > 0) {
			throw new BusinessException("非最新一期的结算单,不能弃审或撤回！");
		}
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		// 参数是单据类型编码字符串 根据需求是否打开下面代码
        /**CommonResponse<String> resp = billTypeApi.checkQuote(billTypeCode, billId);
        if(!resp.isSuccess()){
            return CommonResponse.error("无法撤回！"+resp.getMsg());
        }*/
		return CommonResponse.success();
	}

}

==> ejc-jlcost-impl-3.0.0-20240705.094142-210-sources.jar: com/ejianc/business/jlcost/payout/service/impl/SettleBpmServiceImpl.java <==
package com.ejianc.business.jlcost.payout.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.jlcost.payout.bean.ContractEntity;
import com.ejianc.business.jlcost.payout.bean.SettleEntity;
import com.ejianc.business.jlcost.payout.service.IContractService;
import com.ejianc.business.jlcost.payout.service.ISettleService;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service("settle")
public class SettleBpmServiceImpl implements ICommonBusinessService {

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
	private ISettleService settleService;
    @Autowired
	private IContractService contractService;

	/**
	 * 提交前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {

		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		SettleEntity settleEntity = settleService.selectById(billId);
		if(2 == settleEntity.getSettleType()){
			writeBackCont(settleEntity.getContractId(), true);
		}
		return CommonResponse.success();
	}

	private void writeBackCont(Long contractId, boolean isApprove) {
		LambdaUpdateWrapper<ContractEntity> updateWrapper = new LambdaUpdateWrapper<>();
		updateWrapper.eq(ContractEntity::getId, contractId);
		updateWrapper.set(ContractEntity::getPerformanceStatus, isApprove ? "3" : "2");
		contractService.update(updateWrapper);
	}

	/**
	 * 弃审前事件回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		SettleEntity entity = settleService.selectById(billId);
		LambdaQueryWrapper<SettleEntity> queryWrapper = new LambdaQueryWrapper<>();
		queryWrapper.eq(SettleEntity::getContractId, entity.getContractId());
		queryWrapper.eq(SettleEntity::getProjectId, entity.getProjectId());
		queryWrapper.notIn(SettleEntity::getBillState, BillStateEnum.PASSED_STATE.getBillStateCode(), BillStateEnum.COMMITED_STATE.getBillStateCode());
		SettleEntity settleEntity = settleService.getOne(queryWrapper, false);
		if (null != settleEntity) {
			throw new BusinessException("该合同在该项目上存在未完成的结算单【" + settleEntity.getBillCode() + "】,不能弃审或撤回！");
		}
		queryWrapper = new LambdaQueryWrapper<>();
		queryWrapper.eq(SettleEntity::getContractId, entity.getContractId());
		queryWrapper.eq(SettleEntity::getProjectId, entity.getProjectId());
		queryWrapper.in(SettleEntity::getBillState, BillStateEnum.PASSED_STATE.getBillStateCode(), BillStateEnum.COMMITED_STATE.getBillStateCode());
		queryWrapper.gt(SettleEntity::getCreateTime, entity.getCreateTime());
		if (settleService.count(queryWrapper) > 0) {
			throw new BusinessException("非最新一期的结算单,不能弃审或撤回！");
		}
		if(2 == entity.getSettleType()){
			ContractEntity contractEntity = contractService.selectById(entity.getContractId());
			if (!"2".equals(contractEntity.getPerformanceStatus())){
				throw new BusinessException("合同为非【已封账】状态，不允许弃审最终结算！");
			}
		}
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		SettleEntity settleEntity = settleService.selectById(billId);
		if(2 == settleEntity.getSettleType()){
			writeBackCont(settleEntity.getContractId(), false);
		}
		return CommonResponse.success();
	}

}
